# Changelog

All notable changes to this project will be documented in this file.

## [unreleased]

## [0.1.0rc6] - 2025-01-18

- Bug fix for new Coaxial source input
- Improved group handling with ability to select source
- Improved device specifics

## [0.1.0rc5] - 2025-01-15

- New improved grouping method for better stability
- Add support for LinkMate (WAM-270)

## [0.1.0rc4] - 2024-10-26

- More fixes for URL Playback

## [0.1.0rc3] - 2024-09-05

- Fixes for URL playback
- Small fixes for DLNA attributes

## [0.1.0rc2] - 2024-08-22

- Fixed DLNA bugs

## [0.1.0rc1] - 2024-08-14

NB! This release is versioned as a release candidate only because the need of changing the
requirements in the Samsung WAM integration for Home Assistant. This release is not compatible
with that integration, but that project has set the requirements to pywam>=0.0.1.

- Fixed typo with grouping attributes
- Fixed a bug for 0 volume
- Added play_url feature
- Added support for grouping
- Better logging
- Fixed DLNA bug for play/pause
- Added music info events for DLNA
- Added some new discovered events
- Total rewrite of client module

## [0.0.1] - 2023-03-06

- Initial release

[unreleased]: https://github.com/Strixx76/pywam
[0.0.1]: https://github.com/Strixx76/pywam/tree/v0.0.1
[0.1.0rc1]: https://github.com/Strixx76/pywam/tree/v0.1.0rc1
[0.1.0rc2]: https://github.com/Strixx76/pywam/tree/v0.1.0rc2
[0.1.0rc3]: https://github.com/Strixx76/pywam/tree/v0.1.0rc3
[0.1.0rc4]: https://github.com/Strixx76/pywam/tree/v0.1.0rc4
[0.1.0rc5]: https://github.com/Strixx76/pywam/tree/v0.1.0rc5
[0.1.0rc6]: https://github.com/Strixx76/pywam/tree/v0.1.0rc6
